/// Help content for PrayerTracker
module PrayerTracker.Views.Help

open System.IO
open Giraffe.ViewEngine

/// The help index page
let index () =
    let s   = I18N.localizer.Force()
    let l   = I18N.forView "Help/Index"
    use sw  = new StringWriter()
    let raw = rawLocText sw
    [ p [] [
          raw l["Throughout PrayerTracker, you'll see an icon (a question mark in a circle) next to the title on each page."]; space
          raw l["Clicking this will open a new, small window with directions on using that page."]; space
          raw l["If you are looking for a quick overview of PrayerTracker, start with the “Add / Edit a Request” and “Change Preferences” entries."] ]
      hr []
      p [ _class "pt-center-text" ] [ strong [] [ locStr s["Help Topics"] ] ]
      p [] [ a [ _href "/help/small-group/preferences"  ] [ locStr s["Change Preferences"]     ] ]
      p [] [ a [ _href "/help/small-group/announcement" ] [ locStr s["Send Announcement"]      ] ]
      p [] [ a [ _href "/help/small-group/members"      ] [ locStr s["Maintain Group Members"] ] ]
      p [] [ a [ _href "/help/requests/edit"            ] [ locStr s["Add / Edit a Request"]   ] ]
      p [] [ a [ _href "/help/requests/maintain"        ] [ locStr s["Maintain Requests"]      ] ]
      p [] [ a [ _href "/help/requests/view"            ] [ locStr s["View Request List"]      ] ]
      p [] [ a [ _href "/help/user/log-on"              ] [ locStr s["Log On"]                 ] ]
      p [] [ a [ _href "/help/user/password"            ] [ locStr s["Change Your Password"]   ] ] ]


/// Help for prayer requests
module Requests =
    
    /// Add / Edit a Request
    let edit () =
        let s   = I18N.localizer.Force()
        let l   = I18N.forView "Help/Requests/Edit"
        use sw  = new StringWriter()
        let raw = rawLocText sw
        [ p [] [ raw l["This page allows you to enter or update a new prayer request."] ]
          h2 [] [ locStr s["Request Type"] ]
          p [] [
              raw l["There are 5 request types in PrayerTracker."]; space
              raw l["“Current Requests” are your regular requests that people may have regarding things happening over the next week or so."]; space
              raw l["“Long-Term Requests” are requests that may occur repeatedly or continue indefinitely."]; space
              raw l["“Praise Reports” are like “Current Requests”, but they are answers to prayer to share with your group."]; space
              raw l["“Expecting” is for those who are pregnant."]; space
              raw l["“Announcements” are like “Current Requests”, but instead of a request, they are simply passing information along about something coming up."] ]
          p [] [
              raw l["The order above is the order in which the request types appear on the list."]; space
              raw l["“Long-Term Requests” and “Expecting” are not subject to the automatic expiration (set on the “Change Preferences” page) that the other requests are."] ]
          h2 [] [ locStr s["Date"] ]
          p [] [
              raw l["For new requests, this is a box with a calendar date picker."]; space
              raw l["Click or tab into the box to display the calendar, which will be preselected to today's date."]; space
              raw l["For existing requests, there will be a check box labeled “Check to not update the date”."]; space
              raw l["This can be used if you are correcting spelling or punctuation, and do not have an actual update to make to the request."]
          ]
          h2 [] [ locStr s["Requestor / Subject"] ]
          p [] [
              raw l["For requests or praises, this field is for the name of the person who made the request or offered the praise report."]; space
              raw l["For announcements, this should contain the subject of the announcement."]; space
              raw l["For all types, it is optional; I used to have an announcement with no subject that ran every week, telling where to send requests and updates."] ]
          h2 [] [ locStr s["Expiration"] ]
          p [] [
              raw l["“Expire Normally” means that the request is subject to the expiration days in the group preferences."]; space
              raw l["“Request Never Expires” can be used to make a request never expire (note that this is redundant for “Long-Term Requests” and “Expecting”)."]; space
              raw l["If you are editing an existing request, a third option appears."]; space
              raw l["“Expire Immediately” will make the request expire when it is saved."]; space
              raw l["Apart from the icons on the request maintenance page, this is the only way to expire “Long-Term Requests” and “Expecting” requests, but it can be used for any request type."] ]
          h2 [] [ locStr s["Request"] ]
          p [] [
              raw l["This is the text of the request."]; space
              raw l["The editor provides many formatting capabilities, including “Spell Check as you Type” (enabled by default), “Paste from Word”, and “Paste Plain”, as well as “Source” view, if you want to edit the HTML yourself."]; space
              raw l["It also supports undo and redo, and the editor supports full-screen mode. Hover over each icon to see what each button does."] ] ]
        